package com.helicon.sysanalyzer;

//import java.applet.*;
import java.awt.*;
import java.util.*;
import java.io.*;

/**
 * This is the main class for the HeliconSystemAnalyzer
 *
 * This is command line tool that creates HTML documentation
 * about the system information and directories' and files' structure.
 * If it is launched without the parameters it will popup the simple
 * window allowing for input the necessary parameters.
 * <p>
 * The parameters are:<br>
 * <code>-d</code> or <code>--directories &lt;directories&gt;</code> the name's of directories <br>
 * <code>-of</code> or <code>--onlyNames &lt;extensions&gt;</code> the name's of extensions <br>
 * <code>-ed</code> or <code>--exceptDirs &lt;exceptDirs&gt;</code> to show without these directories<br>
 * <code>-od</code> or <code>--outputDir &lt;outputDir&gt;</code> the name's of output folder for HTML files and ZIP file<br>
 * <code>-sp</code> or <code>--showProgress</code> switches verbose mode on<br>
 * <code>-cz</code> or <code>--createZip</code> switches create ZIP file mode on<br>
 * <code>-h</code> or <code>--help</code> prints usage message and exits<br>
 * <p>
 * The output will be HTML document and ZIP file with the information
 * about the directories' stuctures and files.
 * <p>
 * @author Vladimir Koval &lt;<a href="mailto:kovvl@yahoo.com">kovvl@yahoo.com</a>&gt;
 * @author (c) 2002 Helicon, Ukraine www.helicon.com.ua
 */
public class HeliconSystemAnalyzer {

    private static BufferedReader br = null;
    // names of directories to show
    private static java.lang.String directories = "";
    // extensions of files that could be shown
    //private static java.lang.String onlyExts = "jar;class;xml;";
    private static java.lang.String onlyExts = "";
    // names of files that could be shown
    //    private static java.lang.String onlyNames = "jdk;JDK;websphere;j2sdk;";
    private static java.lang.String onlyNames = "";
    // names of directories NOT to show
    private static java.lang.String exceptDirs = "";
    // names of files NOT to show
    private static java.lang.String exceptFiles = "";
    // names of extensions NOT to show
    private static java.lang.String exceptExts = "";
    // names of output folder
    private static java.lang.String outputDir = "";
    // delimiter of inputed directories
    private static java.lang.String delimiter = ";";
    //createZip mode
    private static boolean createZip = false;
    //verbose mode
    private static boolean verbose = true;
    //contentsJar mode
    private static boolean contentsJar = false;
    //contentsZip mode
    private static boolean contentsZip = false;

    //interactive
    private static boolean interactive = false;
    // root folder
    private static String rootDir = "." + java.io.File.separator;
    private static boolean findPath = false;
    private static String sourcePath = null;

    private static String sortOrder = null;

    private static String currentLineMust = null;
    private static String currentLineMustExts = null;
    boolean flagTomcat = false;
    boolean flagJDK = false;
    boolean flagWebsphere = false;
    boolean flagAnt = false;
    // count of entries to generateOther
    private static int countEntries = 0;

    //sort number : no sort = 0; name = 1 ; date = 2, length = 3
    private static int sortNumber = 3;

    private java.awt.Panel ivjContentsPane = null;

    private IvjEventHandler ivjEventHandler = new IvjEventHandler();
    private IvjItemListenerHandler ivjItemListenerHandler =
        new IvjItemListenerHandler();

    private java.awt.Label ivjHeadLabel = null;
    private java.awt.Label ivjHeadLabel2 = null;
    private java.awt.Label ivjHeadLabel3 = null;
    private java.awt.Label ivjBottomLabel = null;
    private java.awt.Label ivjDirectoriesLabel = null;
    private java.awt.Label ivjOnlyExtsLabel = null;
    private java.awt.Label ivjOnlyExtsLabel2 = null;
    private java.awt.Label ivjOnlyNamesLabel = null;
    private java.awt.Label ivjOnlyNamesLabel2 = null;
    private java.awt.Label ivjDirectoriesLabel2 = null;
    private java.awt.Label ivjDirectoriesLabel3 = null;
    private java.awt.Label ivjIgnoreLabel = null;
    private java.awt.Label ivjExceptDirsLabel = null;
    private java.awt.Label ivjExceptDirsLabel2 = null;
    private java.awt.Label ivjExceptFilesLabel = null;
    private java.awt.Label ivjExceptFilesLabel2 = null;
    private java.awt.Label ivjExceptExtsLabel = null;
    private java.awt.Label ivjExceptExtsLabel2 = null;
    private java.awt.Label ivjOutputDirLabel = null;
    private java.awt.Label ivjOutputDirLabel2 = null;
    private java.awt.Label ivjOutputDirLabel3 = null;
    private java.awt.Label ivjPresetsLabel = null;
    private java.awt.Label ivjArchiveLabel = null;
    private java.awt.Label ivjSortLabel = null;

    private java.awt.Label ivjLineLabel = null;
    private java.awt.Label ivjLineLabel2 = null;
    private java.awt.Label ivjLineLabel3 = null;
    private java.awt.Label ivjLineLabel4 = null;
    public Checkbox ivjCheckboxTomcat = null;
    public Checkbox ivjCheckboxJDK = null;
    public Checkbox ivjCheckboxWebsphere = null;
    public Checkbox ivjCheckboxAnt = null;

    public Checkbox ivjCheckboxZIP = null;
    public Checkbox ivjCheckboxJAR = null;

    public Checkbox ivjCheckboxName = null;
    public Checkbox ivjCheckboxDate = null;
    public Checkbox ivjCheckboxSize = null;


    public CheckboxGroup ivjCheckboxGroupSort = null;

    public java.util.TreeMap htOut = new java.util.TreeMap();
    private java.util.TreeMap tmHelp = new java.util.TreeMap();
    private java.util.TreeMap tmHelpExts = new java.util.TreeMap();

    private static java.util.TreeMap tmOutSystem = new java.util.TreeMap();
    private static java.util.TreeMap tmFilesDir = new java.util.TreeMap();
    private static java.util.Hashtable htContentsJar = new java.util.Hashtable();

    private static java.util.ArrayList alAllFiles = new java.util.ArrayList();
    private static java.util.ArrayList alListAllJars = new java.util.ArrayList();
    private static java.util.ArrayList containsFiles = new java.util.ArrayList();
    private static java.util.ArrayList containsContentsJar = new java.util.ArrayList();


    private static java.util.ArrayList alFilesAll = new java.util.ArrayList();
    private static java.util.ArrayList alContentsAllJar = new java.util.ArrayList();
    private static java.util.Hashtable htContentsAllJar = new java.util.Hashtable();

    private static java.util.TreeMap tmListsJar = new java.util.TreeMap();

    private static String currDir = null;
    //    public String trimDir = null;
    private static java.util.ArrayList alDirList = new java.util.ArrayList();

    private java.util.ArrayList alFindedDirList = new java.util.ArrayList();
    private java.util.ArrayList alRuntimeSystem = new java.util.ArrayList();

    private static long time = 0;
    private static int countGenOther = 0;
    private static String dateRootDir = null;
    public static boolean linux = false;

    //
    /*
       Action action = new AbstractAction("CheckBox Label") {
            // This method is called when the button is pressed
            public void actionPerformed(ActionEvent evt) {
                // Perform action
                JCheckBox cb = (JCheckBox)evt.getSource();

                // Determine status
                boolean isSel = cb.isSelected();
                if (isSel) {
                    // The checkbox is now selected
                } else {
                    // The checkbox is now deselected
                }
            }
        };
    */
    //
    class IvjItemListenerHandler implements java.awt.event.ItemListener {
        public void itemStateChanged(java.awt.event.ItemEvent e) {
            if (e.getSource() == HeliconSystemAnalyzer.this.ivjCheckboxJDK) {
                setHelp();
            }
            if (e.getSource() == HeliconSystemAnalyzer.this.ivjCheckboxTomcat) {
                setHelp();
            }
            if (e.getSource() == HeliconSystemAnalyzer.this.ivjCheckboxWebsphere) {
                setHelp();
            }
            if (e.getSource() == HeliconSystemAnalyzer.this.ivjCheckboxAnt) {
                setHelp();
            }

        }
    }

    /**
     * This class is used for events handling
     */
    class IvjEventHandler implements java.awt.event.ActionListener {
        public void actionPerformed(java.awt.event.ActionEvent e) {
            if (e.getSource() == HeliconSystemAnalyzer.this.getStart())
                connEtoC1(e);
            if (e.getSource() == HeliconSystemAnalyzer.this.getExit())
                connEtoC2(e);
            if (e.getSource() == HeliconSystemAnalyzer.this.getPresets())
                setHelp();

        };

    }

    private java.awt.TextField ivjExceptExts = null;
    private java.awt.TextField ivjDirectories = null;
    private java.awt.Button ivjExit = null;
    private java.awt.Button ivjPresets = null;
    private java.awt.TextField ivjExceptDirs = null;
    private java.awt.Label ivjTablesLabel = null;
    private java.awt.Label ivjCreateZipLabel = null;
    private java.awt.Label ivjVerboseLabel = null;
    private java.awt.Frame ivjMain = null;
    private java.awt.TextField ivjExceptFiles = null;
    private java.awt.TextField ivjOutputDir = null;
    private java.awt.TextField ivjOnlyExts = null;
    private java.awt.TextField ivjOnlyNames = null;
    private java.awt.Button ivjStart = null;
    private java.awt.Checkbox ivjCreateZip = null;
    private java.awt.Checkbox ivjVerbose = null;
    /**
     * Creates new instance of the HeliconSystemAnalyzer class
     * and perfoms it's initialization
     * Should be used only if it is necessary to
     * use AWT interface
     */
    public HeliconSystemAnalyzer() {
        super();

        String s = null;
        findPath = true;

        s = getPropertyOS();
        runtime(s);

        //        if(!linux)
        fillRuntimeSystem();

        //        initialize();

        // compose the line to invoke the runtime method
        /*
                String[] cmd = new String[3];
                findPath = true;
                cmd = getPropertyOS();
                cmd[2] = "set";
                // call the runtime method
                runtime(cmd);
        */
        //		findInputDir();

        //        fillRuntimeSystem();

        java.util.Date nameDate = new java.util.Date();
        dateRootDir =
            java
                .text
                .DateFormat
                .getTimeInstance(java.text.DateFormat.SHORT, java.util.Locale.GERMAN)
                .format(nameDate);

        dateRootDir = dateRootDir.replace(':', '_');

        fillType();

        initialize();
    }
    /**
     * Creates new instance of the HeliconSystemAnalyzer class
     * and perfoms it's initialization
     * Should be used only if it is NOT necessary to
     * use AWT interface
     */
    public HeliconSystemAnalyzer(boolean interactive) {
        super();
        /*
                String[] cmd = new String[3];

                findPath = true;
                // compose the line to invoke the runtime method
                cmd = getPropertyOS();
                cmd[2] = "set";
                // call the runtime method
                runtime(cmd);

                fillRuntimeSystem();

                setDirectories();
        */
    }
    public boolean action(Event evt, Object whichAction) {
        if (evt.target instanceof Checkbox) {
            Checkbox currentCheckbox = (Checkbox) evt.target;
            boolean checkboxState = currentCheckbox.getState();
            setHelp();

        }
        return true;
    }
    /**
     * connEtoC1:  (Button1.action.actionPerformed(java.awt.event.ActionEvent) --> HeliconSystemAnalyzer.startbutton_ActionPerformed(Ljava.awt.event.ActionEvent;)V)
     * @param arg1 java.awt.event.ActionEvent
     */
    /* WARNING: THIS METHOD WILL BE REGENERATED. */
    private void connEtoC1(java.awt.event.ActionEvent arg1) {
        try {
            // user code begin {1}
            // user code end
            this.startbutton_ActionPerformed(arg1);
            // user code begin {2}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {3}
            // user code end
            handleException(ivjExc);
        }
    }
    /**
     * connEtoC2:  (exit.action.actionPerformed(java.awt.event.ActionEvent) --> HeliconSystemAnalyzer.exit_ActionPerformed(Ljava.awt.event.ActionEvent;)V)
     * @param arg1 java.awt.event.ActionEvent
     */
    /* WARNING: THIS METHOD WILL BE REGENERATED. */
    private void connEtoC2(java.awt.event.ActionEvent arg1) {
        try {
            // user code begin {1}
            // user code end
            this.exit_ActionPerformed(arg1);
            // user code begin {2}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {3}
            // user code end
            handleException(ivjExc);
        }
    }
    /**
     * Filling the TreeMap for files that crossing through
     * the all directories
     */
    public void createTMFilesDir() {

        java.util.ArrayList alDirs = new java.util.ArrayList();

        for (int i = 0; i < alFilesAll.size(); i++) {
            java.io.File file = (java.io.File) alFilesAll.get(i);

            if (this.containsFiles.contains(file.getName())) {

                alDirs = (java.util.ArrayList) tmFilesDir.get(file.getName());
                if (alDirs != null) {
                    alDirs.add(file);
                } else {
                    alDirs = new java.util.ArrayList();
                    alDirs.add(file);
                }

                tmFilesDir.put(file.getName(), alDirs);

            } // end if
        } // end for

    }
    /**
     * Filling the TreeMap for files that crossing through
     * the all directories
     */
    public void createTMRepeatedContentsJar() {

        java.util.ArrayList alJars = new java.util.ArrayList();

        java.util.Iterator it = htContentsAllJar.keySet().iterator();
        while (it.hasNext()) {

            java.util.jar.JarEntry content = (java.util.jar.JarEntry) it.next();
//            java.util.jar.JarFile jarFile =
//                (java.util.jar.JarFile) htContentsAllJar.get(content);
            java.io.File jarFile =
                (java.io.File) htContentsAllJar.get(content);

            java.util.Hashtable timeHT = htContentsAllJar;

            java.util.ArrayList timecontainsContentsJar = this.containsContentsJar;

            //            if (this.containsContentsJar.contains(content.getName())) {
            if (this.containsContentsJar.contains(content.getName())) {

                alJars = (java.util.ArrayList) htContentsJar.get(content.getName());
                if (alJars != null) {
                    alJars.add(jarFile);
                } else {
                    alJars = new java.util.ArrayList();
                    alJars.add(jarFile);
                }

                htContentsJar.put(content.getName(), alJars);

            } // end if
        } // end for

    }

    /**
     * Exits application
     */
    static void exit() {
        int status = 0;
        System.exit(status);
    }
    /**
     * Handles Exit button pressing
     */
    public void exit_ActionPerformed(java.awt.event.ActionEvent actionEvent) {
        ivjMain.setVisible(false);
        ivjMain = null;
        exit();
    }
    /**
    * Filling the ArrayList for information about system environment' variables
    */
    public void fillRuntimeSystem() {

        java.util.ArrayList alFindedDirList = new java.util.ArrayList();

        String line = null;

        try {
            while ((line = br.readLine()) != null) {

                alRuntimeSystem.add(line);

                findInputDir(line);

            } // end while
        } catch (Throwable t) {
            t.printStackTrace();
        }

    }
    public void fillType() {

        java.util.ArrayList alJDK = new java.util.ArrayList();
        java.util.ArrayList alTomcat = new java.util.ArrayList();
        java.util.ArrayList alWebsphere = new java.util.ArrayList();
        java.util.ArrayList alAnt = new java.util.ArrayList();

        java.util.ArrayList alJDKExts = new java.util.ArrayList();
        java.util.ArrayList alTomcatExts = new java.util.ArrayList();
        java.util.ArrayList alWebsphereExts = new java.util.ArrayList();
        java.util.ArrayList alAntExts = new java.util.ArrayList();

        alJDK.add("JDK");
        alJDK.add("jakarta-JDK");
        alJDK.add("bin");
        alJDK.add("lib");
        alJDK.add("java");
        alJDK.add("jar");
        alJDK.add("jre");
        alJDK.add("lib");

        alJDK.add("*.jar");
        alJDK.add("*.exe");
        alJDK.add("*.lib");
        alJDK.add("*.idl");

        alTomcat.add("Tomcat");
        alTomcat.add("jakarta");
        alTomcat.add("Catalina");
        alTomcat.add("tomcat-user");
        alTomcat.add("server");
        alTomcat.add("web");
        alTomcat.add("webapps");
        alTomcat.add("lib");
        alTomcat.add("bin");
        alTomcat.add("conf");
        alTomcat.add("classes");
        alTomcat.add("WEB-INF");
        alTomcat.add("ROOT");
        alTomcat.add("catalina");

        alTomcat.add("*.zip");
        alTomcat.add("*.jar");
        alTomcat.add("*.xml");
        alTomcat.add("*.sh");

        alWebsphere.add("Websphere");
        alWebsphere.add("*.lib");

        alAnt.add("jakarta-ant");
        alAnt.add("ant");
        alAnt.add("lib");
        alAnt.add("bin");
        alAnt.add("antRun");
        alAnt.add("jaxp");

        alAnt.add("*.bat");
        alAnt.add("*.jar");
        alAnt.add("*.sh");

        tmHelp.put("JDK", alJDK);
        tmHelp.put("Tomcat", alTomcat);
        tmHelp.put("Websphere", alWebsphere);
        tmHelp.put("Ant", alAnt);

//        tmHelpExts.put("JDK", alJDKExts);
//        tmHelpExts.put("Tomcat", alTomcatExts);
//        tmHelpExts.put("Websphere", alWebsphereExts);
//        tmHelpExts.put("Ant", alWebsphereExts);

    }
    /**
     * Finds all path to different program' packages for example JDK
     */

    public void findInputDir(String line) {

        java.util.ArrayList alToFindDirList = new java.util.ArrayList();
        java.util.ArrayList alFindedDirList = new java.util.ArrayList();

        alToFindDirList.add("Apache JDK 4.0");
        alToFindDirList.add("jakarta-JDK-3.2.1");

        for (int b = 0; b < alToFindDirList.size(); b++) {

            int findInt = line.indexOf((String) alToFindDirList.get(b));
            if (findInt != -1) {
                int beg = line.lastIndexOf(";", findInt);
                //                int end = line.indexOf("\\", findInt);
                int end = line.indexOf(java.io.File.separator, findInt);

                this.directories += delimiter + line.substring(beg + 1, end);

            } //end if
        } // end for

    }
    /**
    * Forces generating main HTML files
    */
    public static void generate() {
        //retreiving current time
        //        time = java.util.Calendar.getInstance().getTime().getTime();
        java.util.ArrayList alFiles = new java.util.ArrayList();

        System.out.println();
        System.out.println("Creating HTML documents. This may take few minutes.");
        try {

            String tttime = outputDir;
            int l = tttime.length();

            if (outputDir.length() != 0) {
                rootDir = outputDir;
            } else {
                //    rootDir += "\\"+dateRootDir;
            }

            if (!rootDir.equals("./"))
                new java.io.File(rootDir).mkdirs();

            //add file seperator at the end of the rootDir if necessary.
            if (!rootDir.endsWith(java.io.File.separator))
                rootDir += java.io.File.separator;

            String time3 = rootDir;

            //creating new HTMLProducerConsole instance
            HTMLProducerConsole hp = new HTMLProducerConsole(linux);

            //writing CSS
            hp.writeCSS(
                new java.io.PrintWriter(
                    new java.io.BufferedWriter(
                        new java.io.FileWriter(rootDir + "stylesheet.css"))));
            //writing main frameset
            hp.writeFrameset(
                new java.io.PrintWriter(
                    new java.io.BufferedWriter(new java.io.FileWriter(rootDir + "index.html"))));
            //writing left top frame with the schema list

            new java.io.File(rootDir + java.io.File.separator + "variables").mkdirs();
            hp.writeMain(
                new java.io.PrintWriter(
                    new java.io.BufferedWriter(new java.io.FileWriter(rootDir + "main.html"))),
                "host",
                "db name",
                "fact conn",
                alDirList,
                tmOutSystem);

            hp.writeAllVarCatalog(
                new java.io.PrintWriter(
                    new java.io.BufferedWriter(
                        new java.io.FileWriter(
                            rootDir + "variables" + java.io.File.separator + "all_varobjects.html"))),
                tmOutSystem);

            hp.writeRightFrame(
                new java.io.PrintWriter(
                    new java.io.BufferedWriter(new java.io.FileWriter(rootDir + "right.html"))));

            java.io.File curr_dir =
                new java.io.File(rootDir + java.io.File.separator + "dirsForFile");
            String s[] = curr_dir.list();

            if (s != null) {
                for (int i = 0; i < s.length; i++) {

                    String fileString = curr_dir + "/" + s[i];

                    java.io.File f = new java.io.File(fileString);
                    f.delete();
                } // end dor

            } // end if

            // delete dirsForFile folder
            new java.io.File(rootDir + java.io.File.separator + "dirsForFile").delete();

            new java.io.File(rootDir + java.io.File.separator + "dirsForFile").mkdirs();

            java.util.Iterator itFile = tmFilesDir.keySet().iterator();

            java.util.TreeMap tmFilesTIME = tmFilesDir;

            while (itFile.hasNext()) {
                //                String schema = (String) it.next();
                String currFile = (String) itFile.next();

                java.util.ArrayList alDirs = (java.util.ArrayList) tmFilesDir.get(currFile);

                alDirs = resortData(alDirs, sortNumber);
                // create html file containing list of directories for the file
                hp.writeDirListForFileContent(
                    new java.io.PrintWriter(
                        new java.io.BufferedWriter(
                            new java.io.FileWriter(
                                rootDir
                                    + "dirsForFile"
                                    + java.io.File.separator
                                    + currFile
                                    + "_dirsList.html"))),
                    currFile,
                    alDirs);
            } //end while

            // for repeated contents in JAR files
            // delete jarsForContent folder
            new java.io.File(rootDir + java.io.File.separator + "jarsForContent").delete();

            new java.io.File(rootDir + java.io.File.separator + "jarsForContent").mkdirs();

            java.util.Iterator itContent = htContentsJar.keySet().iterator();


            while (itContent.hasNext()) {
                //                String schema = (String) it.next();

                //	            java.util.jar.JarEntry currContent = (java.util.jar.JarEntry) itContent.next();
                //        java.util.jar.JarFile jarFile = (java.util.jar.JarFile) htContentsAllJar.get(content);

                //                String currContentStr = (String) currContent.getName() ;
                String currContentStr = (String) itContent.next();
                String currContentLink = currContentStr.replace('/', '_');

                java.util.ArrayList alJarsList =
                    (java.util.ArrayList) htContentsJar.get(currContentStr);

                // create html file containing list of directories for the file
                //                hp.writeDirListForFileContent(
                alJarsList = resortData(alJarsList, sortNumber);

                hp.writeContentListForJar(
                    new java.io.PrintWriter(
                        new java.io.BufferedWriter(
                            new java.io.FileWriter(
                                rootDir
                                    + "jarsForContent"
                                    + java.io.File.separator
                                    + currContentLink
                                    + "_jarsList.html"))),
                    currContentStr,
                    alJarsList,
                    containsFiles,
                    contentsJar,
                    contentsZip);
            } //end while

            //htContentsJar

            // create folder
            new java.io.File(rootDir + "AllFiles").mkdirs();
            // create html file containing all files
            alFilesAll = resortData(alFilesAll, sortNumber);
            hp.writeAllFilesContent(
                new java.io.PrintWriter(
                    new java.io.BufferedWriter(
                        new java.io.FileWriter(
                            rootDir + "AllFiles" + java.io.File.separator + "allFiles" + "_content.html"))),
                containsFiles,
                alFilesAll);

		/// for All jar files
            // create folder
            new java.io.File(rootDir + "AllJars").mkdirs();
            // create html file containing all jars
            alListAllJars = resortData(alListAllJars, sortNumber);
            hp.writeAllJarsContent(
                new java.io.PrintWriter(
                    new java.io.BufferedWriter(
                        new java.io.FileWriter(
                            rootDir + "AllJars" + java.io.File.separator + "allJars" + "_content.html"))),
                containsFiles,
                alListAllJars,
                alFilesAll);

//
            System.out.println(
                "Successfully finished in "
                    + Long.toString(java.util.Calendar.getInstance().getTime().getTime() - time)
                    + " ms");
            /*
                        java.io.File canonPathRoot = new java.io.File(rootDir);
                        String canonPath = canonPathRoot.getCanonicalPath();
                        System.out.println("index.html is located in " + canonPath);
                        runIndex(canonPath);
            */
        } catch (java.lang.Exception e) {
            System.err.println("An error occured");
            e.printStackTrace();
        }

    }
    /**
    * Forces generating secondary HTML files
    */
    public static void generateOther(java.util.TreeMap htOut, String currDirIn) {
        //retreiving current time
        if (countGenOther == 0)
            time = java.util.Calendar.getInstance().getTime().getTime();

        /*
                java.util.Date nameDate = new java.util.Date();
                dateRootDir =
                    java
                        .text
                        .DateFormat
                        .getTimeInstance(java.text.DateFormat.SHORT, java.util.Locale.GERMAN)
                        .format(nameDate);

                dateRootDir = dateRootDir.replace(':', '_');
        */
        java.util.ArrayList alFiles = new java.util.ArrayList();

        countGenOther++;
        //count of entries to generateOther method
        countEntries++;

        try {

            if (outputDir.length() != 0) {
                rootDir = outputDir;
            } else {
                if (countEntries == 1)
                    rootDir += java.io.File.separator + dateRootDir;
            }

            String timeTime = rootDir;

            if (!rootDir.equals("./"))
                new java.io.File(rootDir).mkdirs();

            //add file seperator at the end of the rootDir if necessary.
            if (!rootDir.endsWith(java.io.File.separator))
                rootDir += java.io.File.separator;

            //creating new HTMLProducerConsole instance
            HTMLProducerConsole hp = new HTMLProducerConsole(htOut, linux);

            hp.writeAllCatalog(
                new java.io.PrintWriter(
                    new java.io.BufferedWriter(
                        new java.io.FileWriter(rootDir + "allobjects.html"))),
                tmOutSystem);
            //            new java.io.File(rootDir + currDir.substring(3,currDir.length())).mkdirs();

            ////

            String s = null;
            if (!linux) {
                s =
                    rootDir
                        + currDir.substring(0, 1)
                        + File.separator
                        + currDir.substring(3, currDir.length())
                        + File.separator
                        + "dirobjects.html";
                (new File(rootDir
                    + currDir.substring(0, 1)
                    + File.separator
                    + currDir.substring(3, currDir.length())))
                    .mkdirs();
            } else {
                s = rootDir + currDir + File.separator + "dirobjects.html";
                (new File(rootDir + currDir)).mkdirs();
            }

            ////

            /*
                        new java
                            .io
                            .File(
                                rootDir
                                    + currDir.substring(0, 1)
                                    + java.io.File.separator
                                    + currDir.substring(3, currDir.length()))
                            .mkdirs();

                        hp.writeDirCatalog(
                            new java.io.PrintWriter(
                                new java.io.BufferedWriter(
                                    new java.io.FileWriter(
                                        rootDir
                                            + currDir.substring(0, 1)
                                            + java.io.File.separator
                                            + currDir.substring(3, currDir.length())
                                            + java.io.File.separator
                                            + "dirobjects.html"))),
                            currDir);
            */
            hp.writeDirCatalog(
                new PrintWriter(new BufferedWriter(new FileWriter(s))),
                currDir);

            //                        new java.io.FileWriter(rootDir + currDir.substring(flash+1,currDir.length()) + "_dirobjects.html"))));

            //dealing with the each

            float sizeOfDir = htOut.size();
            int currPercentCount = 0;
            float onePerCent = sizeOfDir / 100;
            int purePercent = 1;

            System.out.println("");
            System.out.println("Current folder: " + currDirIn);
            System.out.println("");

            java.util.Iterator it = htOut.keySet().iterator();
            while (it.hasNext()) {

                currPercentCount++;

                /*
                				if (currPercentCount >= onePerCent){

                					System.out.println("Current percent of performed directories: "+purePercent+" %");
                					onePerCent =+ onePerCent;
                					purePercent++;

                				}

                */
                float time2 = (100 / sizeOfDir);
                float timeCount = ((float) 100 / sizeOfDir) * currPercentCount;
                int newtimeCount = (int) timeCount;

                //				System.out.println("Current percent of performed directories: "+timeCount+" %");
                //				System.out.print("Current percent of performed directories: "+newtimeCount+" %");

                ////
                String currDir = (String) it.next();
                String currPath = null;
                if (!linux) {
                    currPath =
                        currDir.substring(0, 1)
                            + java.io.File.separator
                            + currDir.substring(3, currDir.length());
                } else {
                    currPath = currDir;
                }

                ////
                /*

                                String currDir = (String) it.next();

                                String currPath =
                                    currDir.substring(0, 1)
                                        + java.io.File.separator
                                        + currDir.substring(3, currDir.length());
                */
                if (verbose)
                    System.out.println(
                        "(" + newtimeCount + "%)" + "Loading objects from " + currDir);
                //creating necessary directories
                //                new java.io.File(rootDir + schema + java.io.File.separator + "tables").mkdirs();
                new java
                    .io
                    .File(rootDir + currPath + java.io.File.separator + "directories")
                    .mkdirs();

                //                if (verbose)
                //                      System.out.println("Generating " + currPath + " table content...");

                alFiles = (java.util.ArrayList) htOut.get(currDir);

                // sort comparator
                alFiles = resortData(alFiles, sortNumber);

                // create html file containing list of files
                Object currFile =
                    hp.writeObjectContent(
                        new java.io.PrintWriter(
                            new java.io.BufferedWriter(
                                new java.io.FileWriter(
                                    rootDir
                                        + currPath
                                        + java.io.File.separator
                                        + "directories"
                                        + "_content.html"))),
                        currPath,
                        alFiles,
                        containsFiles,
                        currDir,
                        contentsJar,
                        contentsZip
                        );

                for (int i = 0; i < alFiles.size(); i++) {

                    java.io.File file = (java.io.File) alFiles.get(i);

                    int point = file.getName().lastIndexOf(".");
                    String ext = file.getName().substring(point + 1, file.getName().length());

                    //                    if ((contentsJar) || (contentsZip)){
                    //                    if (ext.equals("jar") || (ext.equals("zip"))) {
                    if ((ext.equals("jar") && contentsJar) || (ext.equals("zip") && contentsZip)) {

                        java.util.ArrayList alJarFiles =
                            (java.util.ArrayList) tmListsJar.get(file.getAbsolutePath());

                // sort comparator
                alJarFiles = resortData(alJarFiles, sortNumber);

                        hp.writeJarContent(
                            new java.io.PrintWriter(
                                new java.io.BufferedWriter(
                                    new java.io.FileWriter(
                                        rootDir
                                            + currPath
                                            + java.io.File.separator
                                            + file.getName()
                                            + "_content.html"))),
                            currPath,
                            alJarFiles,
                            containsContentsJar,
                            file,
                            currDir);
                    }
//                }

            }

            alAllFiles.add(currFile);

        } //end while

        new java.io.File(rootDir + java.io.File.separator + "variables").mkdirs();
        //dealing with the each value of System Information

        java.util.Iterator itSys = tmOutSystem.keySet().iterator();
        while (itSys.hasNext()) {

            String currVar = (String) itSys.next();
            String currValue = (String) tmOutSystem.get(currVar);

            // create html file containing list of directories for the file
            hp.writeSystemInfoContent(
                new java.io.PrintWriter(
                    new java.io.BufferedWriter(
                        new java.io.FileWriter(
                            rootDir
                                + "variables"
                                + java.io.File.separator
                                + currVar
                                + "_varobjects.html"))),
                currVar,
                currValue);
        } //end while

    } catch (java.lang.Exception e) {
        System.err.println("An error occured");
        e.printStackTrace();
    }
    //		  System.exit(1);

}
/**
 * Returns the command line argument with the specified index from the array
 * @param args the array of command line arguments
 * @param index the index of the argument being retrieved
 * @return the command line argument with the specified index
 */
static String getArg(String[] args, int index) {
    if (index > args.length) {
        usage();
        exit();
    };
    String retStr = new String(args[index]);
    return retStr;
}
/**
 * Return the Head property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getBottomLabel() {
    if (ivjBottomLabel == null) {
        try {
            ivjBottomLabel = new java.awt.Label();
            ivjBottomLabel.setName("BottomLabel");
            ivjBottomLabel.setFont(new java.awt.Font("SansSerif", 1, 11));
            //                ivjBottomLabel.setAlignment(java.awt.Label.CENTER);
            ivjBottomLabel.setText(
                "* strings should be separated by semicolon (i.e.:  bin;JDK;system)");
            ivjBottomLabel.setBounds(10, 380, 450, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjBottomLabel;
}
/**
 * Return the Checkbox1 property value.
 * @return java.awt.Checkbox
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.Checkbox getCheckboxAnt() {
    if (ivjCheckboxAnt == null) {
        try {
            ivjCheckboxAnt = new java.awt.Checkbox();
            ivjCheckboxAnt.setName("CheckboxAnt");
            ivjCheckboxAnt.setBounds(465, 205, 91, 20);
            //                ivjCheckboxAnt.setForeground(new java.awt.Color(0, 69, 244));
            ivjCheckboxAnt.setLabel("Ant");
            ivjCheckboxAnt.setState(false);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxAnt;
}
/**
 * Return the CheckboxGroup1 property value.
 * @return java.awt.CheckboxGroup
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.CheckboxGroup getCheckboxGroupSort() {
    if (ivjCheckboxGroupSort == null) {
        try {
            ivjCheckboxGroupSort = new java.awt.CheckboxGroup();
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxGroupSort;
}
/**
 * Return the Checkbox1 property value.
 * @return java.awt.Checkbox
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.Checkbox getCheckboxJDK() {
    if (ivjCheckboxJDK == null) {
        try {
            ivjCheckboxJDK = new java.awt.Checkbox();
            ivjCheckboxJDK.setName("CheckboxJDK");
            ivjCheckboxJDK.setBounds(465, 165, 91, 20);
            //                ivjCheckboxJDK.setForeground(new java.awt.Color(0, 69, 244));
            ivjCheckboxJDK.setLabel("JDK");
            ivjCheckboxJDK.setState(false);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxJDK;
}
/**
 * Return the Checkbox1 property value.
 * @return java.awt.Checkbox
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.Checkbox getCheckboxTomcat() {
    if (ivjCheckboxTomcat == null) {
        try {
            ivjCheckboxTomcat = new java.awt.Checkbox();
            ivjCheckboxTomcat.setName("CheckboxTomcat");
            ivjCheckboxTomcat.setBounds(465, 145, 91, 20);
            //                ivjCheckboxTomcat.setForeground(new java.awt.Color(0, 69, 244));
            ivjCheckboxTomcat.setLabel("Tomcat");
            ivjCheckboxTomcat.setState(false);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxTomcat;
}
/**
 * Return the Checkbox1 property value.
 * @return java.awt.Checkbox
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.Checkbox getCheckboxWebsphere() {
    if (ivjCheckboxWebsphere == null) {
        try {
            ivjCheckboxWebsphere = new java.awt.Checkbox();
            ivjCheckboxWebsphere.setName("CheckboxWebsphere");
            ivjCheckboxWebsphere.setBounds(465, 185, 91, 20);
            //                ivjCheckboxWebsphere.setForeground(new java.awt.Color(0, 69, 244));
            ivjCheckboxWebsphere.setLabel("Websphere");
            ivjCheckboxWebsphere.setState(false);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxWebsphere;
}
/**
 * Return the Checkbox1 property value.
 * @return java.awt.Checkbox
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.Checkbox getCheckboxJAR() {
    if (ivjCheckboxJAR == null) {
        try {
            ivjCheckboxJAR = new java.awt.Checkbox();
            ivjCheckboxJAR.setName("CheckboxJAR");
            ivjCheckboxJAR.setBounds(465, 278, 91, 23);
            //                ivjCheckboxJAR.setForeground(new java.awt.Color(0, 69, 244));
            ivjCheckboxJAR.setLabel("JAR");
            ivjCheckboxJAR.setState(false);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxJAR;
}
/**
 * Return the Checkbox1 property value.
 * @return java.awt.Checkbox
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.Checkbox getCheckboxZIP() {
    if (ivjCheckboxZIP == null) {
        try {
            ivjCheckboxZIP = new java.awt.Checkbox();
            ivjCheckboxZIP.setName("CheckboxZIP");
            ivjCheckboxZIP.setBounds(465, 300, 91, 23);
            //                ivjCheckboxZIP.setForeground(new java.awt.Color(0, 69, 244));
            ivjCheckboxZIP.setLabel("ZIP");
            ivjCheckboxZIP.setState(false);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxZIP;
}
/**
 * Return the Checkbox1 property value.
 * @return java.awt.Checkbox
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.Checkbox getCheckboxName() {
    if (ivjCheckboxName == null) {
        try {
            ivjCheckboxName = new java.awt.Checkbox();
            ivjCheckboxName.setName("CheckboxName");
            ivjCheckboxName.setBounds(465, 50, 91, 23);
            //                ivjCheckboxName.setForeground(new java.awt.Color(0, 69, 244));
            ivjCheckboxName.setLabel("Name");
            ivjCheckboxName.setCheckboxGroup(getCheckboxGroupSort());
            ivjCheckboxName.setState(true);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxName;
}
/**
 * Return the Checkbox1 property value.
 * @return java.awt.Checkbox
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.Checkbox getCheckboxDate() {
    if (ivjCheckboxDate == null) {
        try {
            ivjCheckboxDate = new java.awt.Checkbox();
            ivjCheckboxDate.setName("CheckboxDate");
            ivjCheckboxDate.setBounds(465, 70, 91, 23);
            //                ivjCheckboxDate.setForeground(new java.awt.Color(0, 69, 244));
            ivjCheckboxDate.setLabel("Date");
            ivjCheckboxDate.setCheckboxGroup(getCheckboxGroupSort());
            ivjCheckboxDate.setState(false);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxDate;
}
/**
 * Return the Checkbox1 property value.
 * @return java.awt.Checkbox
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
public java.awt.Checkbox getCheckboxSize() {
    if (ivjCheckboxSize == null) {
        try {
            ivjCheckboxSize = new java.awt.Checkbox();
            ivjCheckboxSize.setName("CheckboxSize");
            ivjCheckboxSize.setBounds(465, 90, 91, 23);
            //                ivjCheckboxSize.setForeground(new java.awt.Color(0, 69, 244));
            ivjCheckboxSize.setLabel("Size");
            ivjCheckboxSize.setCheckboxGroup(getCheckboxGroupSort());
            ivjCheckboxSize.setState(false);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCheckboxSize;
}

/**
 * Return the ContentsPane property value.
 * @return java.awt.Panel
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Panel getContentsPane() {
    if (ivjContentsPane == null) {
        try {
            ivjContentsPane = new java.awt.Panel();
            ivjContentsPane.setName("ContentsPane");
            ivjContentsPane.setLayout(null);
            getContentsPane().add(getHeadLabel(), getHeadLabel().getName());
            getContentsPane().add(getHeadLabel2(), getHeadLabel2().getName());
            getContentsPane().add(getHeadLabel3(), getHeadLabel3().getName());
            //getContentsPane().add(getBottomLabel(), getBottomLabel().getName());
            getContentsPane().add(getDirectoriesLabel(), getDirectoriesLabel().getName());
//            getContentsPane().add(getOnlyExtsLabel(), getOnlyExtsLabel().getName());
            getContentsPane().add(getOnlyNamesLabel(), getOnlyNamesLabel().getName());
            getContentsPane().add(getDirectoriesLabel2(), getDirectoriesLabel2().getName());
            //getContentsPane().add(getIgnoreLabel(), getIgnoreLabel().getName());
            getContentsPane().add(getExceptDirsLabel(), getExceptDirsLabel().getName());
            getContentsPane().add(getExceptDirsLabel2(), getExceptDirsLabel2().getName());
            getContentsPane().add(getOnlyNamesLabel2(), getOnlyNamesLabel2().getName());
//            getContentsPane().add(getOnlyExtsLabel2(), getOnlyExtsLabel2().getName());
//            getContentsPane().add(getExceptFilesLabel(), getExceptFilesLabel().getName());
//            getContentsPane().add(getExceptFilesLabel2(), getExceptFilesLabel2().getName());
//            getContentsPane().add(getExceptExtsLabel(), getExceptExtsLabel().getName());
//            getContentsPane().add(getExceptExtsLabel2(), getExceptExtsLabel2().getName());
            getContentsPane().add(getOutputDirLabel(), getOutputDirLabel().getName());
            getContentsPane().add(getOutputDirLabel2(), getOutputDirLabel2().getName());
            // getContentsPane().add(getOutputDirLabel3(), getOutputDirLabel3().getName());
            getContentsPane().add(getCreateZipLabel(), getCreateZipLabel().getName());
            getContentsPane().add(getVerboseLabel(), getVerboseLabel().getName());
            getContentsPane().add(getPresetsLabel(), getPresetsLabel().getName());
            getContentsPane().add(getArchiveLabel(), getArchiveLabel().getName());
            getContentsPane().add(getSortLabel(), getSortLabel().getName());
            getContentsPane().add(getExceptDirs(), getExceptDirs().getName());
//            getContentsPane().add(getExceptFiles(), getExceptFiles().getName());
            getContentsPane().add(getDirectories(), getDirectories().getName());
//            getContentsPane().add(getOnlyExts(), getOnlyExts().getName());
            getContentsPane().add(getOnlyNames(), getOnlyNames().getName());
            getContentsPane().add(getStart(), getStart().getName());
//            getContentsPane().add(getExceptExts(), getExceptExts().getName());
            getContentsPane().add(getOutputDir(), getOutputDir().getName());
            getContentsPane().add(getCreateZip(), getCreateZip().getName());
            getContentsPane().add(getVerbose(), getVerbose().getName());
            getContentsPane().add(getExit(), getExit().getName());
            //getContentsPane().add(getPresets(), getPresets().getName());
            getContentsPane().add(getLineLabel(), getLineLabel().getName());
            getContentsPane().add(getLineLabel2(), getLineLabel2().getName());
            getContentsPane().add(getLineLabel3(), getLineLabel3().getName());
            getContentsPane().add(getLineLabel4(), getLineLabel4().getName());
            getContentsPane().add(getCheckboxTomcat(), getCheckboxTomcat().getName());
            getContentsPane().add(getCheckboxWebsphere(), getCheckboxWebsphere().getName());
            getContentsPane().add(getCheckboxAnt(), getCheckboxAnt().getName());
            getContentsPane().add(getCheckboxJDK(), getCheckboxJDK().getName());
            getContentsPane().add(getCheckboxJAR(), getCheckboxJAR().getName());
            getContentsPane().add(getCheckboxZIP(), getCheckboxZIP().getName());

            getContentsPane().add(getCheckboxName(), getCheckboxName().getName());
            getContentsPane().add(getCheckboxDate(), getCheckboxDate().getName());
            getContentsPane().add(getCheckboxSize(), getCheckboxSize().getName());
        } catch (java.lang.Throwable ivjExc) {
            handleException(ivjExc);
        }
    }
    return ivjContentsPane;
}
/**
* Return the Checkbox1 property value.
* @return java.awt.Checkbox
*/
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Checkbox getCreateZip() {
    if (ivjCreateZip == null) {
        try {
            ivjCreateZip = new java.awt.Checkbox();
            ivjCreateZip.setName("createZip");
            ivjCreateZip.setBounds(200, 300, 91, 23);
            ivjCreateZip.setLabel("");
            ivjCreateZip.setState(true);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCreateZip;
}
/*
 * Return the DriverLabel62 property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getCreateZipLabel() {
    if (ivjCreateZipLabel == null) {
        try {
            ivjCreateZipLabel = new java.awt.Label();
            ivjCreateZipLabel.setName("CreateZipLabel");
            ivjCreateZipLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjCreateZipLabel.setText("Create zip-file with results:");
            ivjCreateZipLabel.setBounds(10, 300, 190, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjCreateZipLabel;
}
/**
 * Return the TextField14 property value.
 * @return java.awt.TextField
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.TextField getDirectories() {
    if (ivjDirectories == null) {
        try {
            ivjDirectories = new java.awt.TextField();
            ivjDirectories.setName("driver");
            ivjDirectories.setBounds(200, 45, 235, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjDirectories;
}
/**
 * Return the ivjDirectoriesLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getDirectoriesLabel() {
    if (ivjDirectoriesLabel == null) {
        try {
            ivjDirectoriesLabel = new java.awt.Label();
            ivjDirectoriesLabel.setName("DirectoriesLabel");
            ivjDirectoriesLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjDirectoriesLabel.setText("Analyse folders :");
            ivjDirectoriesLabel.setBounds(10, 45, 150, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjDirectoriesLabel;
}
/**
 * Return the ivjDirectoriesLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getDirectoriesLabel2() {
    if (ivjDirectoriesLabel2 == null) {
        try {
            ivjDirectoriesLabel2 = new java.awt.Label();
            ivjDirectoriesLabel2.setName("DirectoriesLabel2");
            ivjDirectoriesLabel2.setFont(new java.awt.Font("SansSerif", 0, 12));
            if (!linux) {
                ivjDirectoriesLabel2.setText("i.e.:  c:\\JDK3.2.1; d:\\test");
            } else {
                ivjDirectoriesLabel2.setText(
                    "i.e.:  /usr/local/j2sdk1.4.0; /usr/local/j2sdk1.3.1");
            }
            ivjDirectoriesLabel2.setBounds(200, 70, 150, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjDirectoriesLabel2;
}
/**
 * Return the ivjDirectoriesLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getDirectoriesLabel3() {
    if (ivjDirectoriesLabel3 == null) {
        try {
            ivjDirectoriesLabel3 = new java.awt.Label();
            ivjDirectoriesLabel3.setName("DirectoriesLabel3");
            ivjDirectoriesLabel3.setFont(new java.awt.Font("SansSerif", 1, 12));
            ivjDirectoriesLabel3.setText("   (separated by semicolon):");
            ivjDirectoriesLabel3.setBounds(10, 85, 150, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjDirectoriesLabel3;
}
/**
 * Return the TextField1 property value.
 * @return java.awt.TextField
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.TextField getExceptDirs() {
    if (ivjExceptDirs == null) {
        try {
            ivjExceptDirs = new java.awt.TextField();
            ivjExceptDirs.setName("ExceptDirs");
            ivjExceptDirs.setBounds(200, 175, 235, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExceptDirs;
}
/**
 * Return the HostLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getExceptDirsLabel() {
    if (ivjExceptDirsLabel == null) {
        try {
            ivjExceptDirsLabel = new java.awt.Label();
            ivjExceptDirsLabel.setName("ExceptDirsLabel");
            ivjExceptDirsLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            //ivjExceptDirsLabel.setFont(new java.awt.Font("dialog", 0, 12));
            ivjExceptDirsLabel.setText("Ignore folders/files equal to:");
            ivjExceptDirsLabel.setBounds(10, 175, 175, 23);

            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExceptDirsLabel;
}
/**
 * Return the HostLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getExceptDirsLabel2() {
    if (ivjExceptDirsLabel2 == null) {
        try {
            ivjExceptDirsLabel2 = new java.awt.Label();
            ivjExceptDirsLabel2.setName("ExceptDirsLabel2");
            ivjExceptDirsLabel2.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjExceptDirsLabel2.setText("'*','?' are allowed i.e.:  Hel*on?.*txt; *.exe;");
            ivjExceptDirsLabel2.setBounds(200, 200, 250, 21);

            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExceptDirsLabel2;
}
/**
 * Return the TextField141 property value.
 * @return java.awt.TextField
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.TextField getExceptExts() {
    if (ivjExceptExts == null) {
        try {
            ivjExceptExts = new java.awt.TextField();
            ivjExceptExts.setName("ExceptExts");
            ivjExceptExts.setBounds(200, 300, 235, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExceptExts;
}
/**
 * Return the DriverLabel3 property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getExceptExtsLabel() {
    if (ivjExceptExtsLabel == null) {
        try {
            ivjExceptExtsLabel = new java.awt.Label();
            ivjExceptExtsLabel.setName("ExceptExtsLabel");
            ivjExceptExtsLabel.setText("Ignore files with extensions:");
            ivjExceptExtsLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjExceptExtsLabel.setBounds(10, 300, 160, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExceptExtsLabel;
}
/**
 * Return the DriverLabel3 property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getExceptExtsLabel2() {
    if (ivjExceptExtsLabel2 == null) {
        try {
            ivjExceptExtsLabel2 = new java.awt.Label();
            ivjExceptExtsLabel2.setName("ExceptExtsLabel2");
            ivjExceptExtsLabel2.setText("i.e.:  jar; *.txt; bak");
            ivjExceptExtsLabel2.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjExceptExtsLabel2.setBounds(200, 325, 150, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExceptExtsLabel2;
}
/**
 * Return the TextField13 property value.
 * @return java.awt.TextField
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.TextField getExceptFiles() {
    if (ivjExceptFiles == null) {
        try {
            ivjExceptFiles = new java.awt.TextField();
            ivjExceptFiles.setName("ExceptFiles");
            ivjExceptFiles.setBounds(200, 250, 235, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExceptFiles;
}
/**
 * Return the DriverLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getExceptFilesLabel() {
    if (ivjExceptFilesLabel == null) {
        try {
            ivjExceptFilesLabel = new java.awt.Label();
            ivjExceptFilesLabel.setName("ExceptFilesLabel");
            ivjExceptFilesLabel.setText("Ignore file names containing:");
            ivjExceptFilesLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjExceptFilesLabel.setBounds(10, 250, 190, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExceptFilesLabel;
}
/**
 * Return the DriverLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getExceptFilesLabel2() {
    if (ivjExceptFilesLabel2 == null) {
        try {
            ivjExceptFilesLabel2 = new java.awt.Label();
            ivjExceptFilesLabel2.setName("ExceptFilesLabel2");
            ivjExceptFilesLabel2.setText("i.e.:  helicon.jar; autoexec.bat; helicon.bak");
            ivjExceptFilesLabel2.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjExceptFilesLabel2.setBounds(200, 275, 260, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExceptFilesLabel2;
}
/**
 * Return the Button2 property value.
 * @return java.awt.Button
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Button getExit() {
    if (ivjExit == null) {
        try {
            ivjExit = new java.awt.Button();
            ivjExit.setName("exit");
            ivjExit.setBounds(379, 335, 56, 23);
            ivjExit.setLabel("Exit");
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjExit;
}
/**
 * Return the Head property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getHeadLabel() {
    if (ivjHeadLabel == null) {
        try {
            ivjHeadLabel = new java.awt.Label();
            ivjHeadLabel.setName("HeadLabel");
            ivjHeadLabel.setFont(new java.awt.Font("SansSerif", 0, 18));
            ivjHeadLabel.setAlignment(java.awt.Label.CENTER);
            ivjHeadLabel.setText("Helicon System Analyzer");
            ivjHeadLabel.setBounds(50, 11, 480, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjHeadLabel;
}
/**
 * Return the Head property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getHeadLabel2() {
    if (ivjHeadLabel2 == null) {
        try {
            ivjHeadLabel2 = new java.awt.Label();
            ivjHeadLabel2.setName("HeadLabel2");
            ivjHeadLabel2.setFont(new java.awt.Font("SansSerif", 0, 11));
            ivjHeadLabel2.setAlignment(java.awt.Label.CENTER);
            ivjHeadLabel2.setText(
                "\"Java projects outsourcing and outtasking: best performance-to-price ratio\"");
            ivjHeadLabel2.setBounds(30, 380, 530, 23);
            ivjHeadLabel2.setForeground(new java.awt.Color(111, 44, 200));
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjHeadLabel2;
}
/**
 * Return the Head property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getHeadLabel3() {
    if (ivjHeadLabel3 == null) {
        try {
            ivjHeadLabel3 = new java.awt.Label();
            ivjHeadLabel3.setName("HeadLabel2");
            ivjHeadLabel3.setFont(new java.awt.Font("SansSerif", 0, 11));
            ivjHeadLabel3.setAlignment(java.awt.Label.CENTER);
            ivjHeadLabel3.setText(
                "Helicon (c) 2001-2002, www.helicon-soft.com, e-mail: mail@helicon.com.ua");
            ivjHeadLabel3.setBounds(30, 360, 530, 23);
            //ivjHeadLabel3.setForeground(new java.awt.Color(111,44,200));
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjHeadLabel3;
}
/**
 * Return the ivjDirectoriesLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getIgnoreLabel() {
    if (ivjIgnoreLabel == null) {
        try {
            ivjIgnoreLabel = new java.awt.Label();
            ivjIgnoreLabel.setName("IgnoreLabel");
            ivjIgnoreLabel.setFont(new java.awt.Font("SansSerif", 0, 16));
            ivjIgnoreLabel.setText("Ignore:");
            ivjIgnoreLabel.setBounds(10, 120, 150, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjIgnoreLabel;
}
/**
 * Return the LineLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getLineLabel() {
    if (ivjLineLabel == null) {
        try {
            ivjLineLabel = new java.awt.Label();
            ivjLineLabel.setName("LineLabel");
            ivjLineLabel.setText("");
            ivjLineLabel.setBackground(new java.awt.Color(186, 160, 111));
            ivjLineLabel.setBounds(150, 34, 260, 2);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjLineLabel;
}
/**
 * Return the LineLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getLineLabel2() {
    if (ivjLineLabel2 == null) {
        try {
            ivjLineLabel2 = new java.awt.Label();
            ivjLineLabel2.setName("LineLabel2");
            ivjLineLabel2.setText("");
            ivjLineLabel2.setBackground(new java.awt.Color(186, 160, 111));
            ivjLineLabel2.setBounds(9, 120, 550, 2);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjLineLabel2;
}
/**
 * Return the LineLabel3 property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getLineLabel3() {
    if (ivjLineLabel3 == null) {
        try {
            ivjLineLabel3 = new java.awt.Label();
            ivjLineLabel3.setName("LineLabel3");
            ivjLineLabel3.setText("");
            ivjLineLabel3.setBackground(new java.awt.Color(186, 160, 111));
            ivjLineLabel3.setBounds(9, 170, 426, 2);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjLineLabel3;
}
/**
 * Return the LineLabel3 property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getLineLabel4() {
    if (ivjLineLabel4 == null) {
        try {
            ivjLineLabel4 = new java.awt.Label();
            ivjLineLabel4.setName("LineLabel4");
            ivjLineLabel4.setText("");
            ivjLineLabel4.setBackground(new java.awt.Color(186, 160, 111));
            ivjLineLabel4.setBounds(9, 245, 550, 2);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjLineLabel4;
}

/**
 * Return the Frame1 property value.
 * @return java.awt.Frame
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Frame getMain() {
    if (ivjMain == null) {
        try {
            ivjMain = new java.awt.Frame();
            ivjMain.setName("main");
            ivjMain.setLayout(new java.awt.BorderLayout());

            //                ivjMain.setBackground(new java.awt.Color(30, 203, 255));
            ivjMain.setBackground(new java.awt.Color(186, 183, 137));

            //                ivjMain.setBounds(83, 7, 460, 530);
            ivjMain.setBounds(83, 7, 585, 440);
            ivjMain.setVisible(true);
            ivjMain.setTitle("Helicon System Analyzer");
            getMain().add(getContentsPane(), "Center");
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjMain;
}
/**
 * Return the TextField14 property value.
 * @return java.awt.TextField
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.TextField getOnlyExts() {
    if (ivjOnlyExts == null) {
        try {
            ivjOnlyExts = new java.awt.TextField();
            ivjOnlyExts.setName("onlyExts");
            ivjOnlyExts.setBounds(200, 150, 235, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOnlyExts;
}
/**
 * Return the ivjDirectoriesLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getOnlyExtsLabel() {
    if (ivjOnlyExtsLabel == null) {
        try {
            ivjOnlyExtsLabel = new java.awt.Label();
            ivjOnlyExtsLabel.setName("OnlyExtsLabel");
            ivjOnlyExtsLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjOnlyExtsLabel.setText("Show only files with extensions:");
            ivjOnlyExtsLabel.setBounds(10, 150, 175, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOnlyExtsLabel;
}
/**
 * Return the HostLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getOnlyExtsLabel2() {
    if (ivjOnlyExtsLabel2 == null) {
        try {
            ivjOnlyExtsLabel2 = new java.awt.Label();
            ivjOnlyExtsLabel2.setName("OnlyExtsLabel2");
            ivjOnlyExtsLabel2.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjOnlyExtsLabel2.setText("i.e.:  bat; class; jar");
            ivjOnlyExtsLabel2.setBounds(200, 175, 150, 21);

            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOnlyExtsLabel2;
}
/**
 * Return the TextField14 property value.
 * @return java.awt.TextField
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.TextField getOnlyNames() {
    if (ivjOnlyNames == null) {
        try {
            ivjOnlyNames = new java.awt.TextField();
            ivjOnlyNames.setName("onlyNames");
            ivjOnlyNames.setBounds(200, 125, 235, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOnlyNames;
}
/**
 * Return the ivjDirectoriesLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getOnlyNamesLabel() {
    if (ivjOnlyNamesLabel == null) {
        try {
            ivjOnlyNamesLabel = new java.awt.Label();
            ivjOnlyNamesLabel.setName("OnlyNamesLabel");
            ivjOnlyNamesLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjOnlyNamesLabel.setText("Show only folders/files containing:");
            ivjOnlyNamesLabel.setBounds(10, 125, 187, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOnlyNamesLabel;
}
/**
 * Return the HostLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getOnlyNamesLabel2() {
    if (ivjOnlyNamesLabel2 == null) {
        try {
            ivjOnlyNamesLabel2 = new java.awt.Label();
            ivjOnlyNamesLabel2.setName("OnlyNamesLabel2");
            ivjOnlyNamesLabel2.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjOnlyNamesLabel2.setText("'*','?' are allowed i.e.:  Hel*on?.*txt; *.exe;");
            ivjOnlyNamesLabel2.setBounds(200, 150, 250, 20);

            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOnlyNamesLabel2;
}
/**
 * Return the TextField14 property value.
 * @return java.awt.TextField
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.TextField getOutputDir() {
    if (ivjOutputDir == null) {
        try {
            ivjOutputDir = new java.awt.TextField();
            ivjOutputDir.setName("outputDir");
            ivjOutputDir.setBounds(200, 250, 235, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOutputDir;
}
/**
 * Return the ivjOutputDirLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getOutputDirLabel() {
    if (ivjOutputDirLabel == null) {
        try {
            ivjOutputDirLabel = new java.awt.Label();
            ivjOutputDirLabel.setName("OutputDirLabel");
            //                ivjOutputDirLabel.setFont(new java.awt.Font("SansSerif", 1, 12));
            ivjOutputDirLabel.setText("Save results in folder: ");
            ivjOutputDirLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjOutputDirLabel.setBounds(10, 250, 150, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOutputDirLabel;
}
/**
 * Return the ivjOutputDirLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getOutputDirLabel2() {
    if (ivjOutputDirLabel2 == null) {
        try {
            ivjOutputDirLabel2 = new java.awt.Label();
            ivjOutputDirLabel2.setName("OutputDirLabel2");
            if (!linux) {
                ivjOutputDirLabel2.setText("i.e.:  c:\\systemInfo");
            } else {
                ivjOutputDirLabel2.setText("i.e.:  /home/smith/systemAnalyzer");
            }

            ivjOutputDirLabel2.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjOutputDirLabel2.setBounds(200, 275, 150, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOutputDirLabel2;
}
/**
 * Return the ivjOutputDirLabel property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getOutputDirLabel3() {
    if (ivjOutputDirLabel3 == null) {
        try {
            ivjOutputDirLabel3 = new java.awt.Label();
            ivjOutputDirLabel3.setName("OutputDirLabel3");
            ivjOutputDirLabel3.setFont(new java.awt.Font("SansSerif", 1, 11));
            ivjOutputDirLabel3.setText(
                "**  leave empty to save results in current folder ");
            ivjOutputDirLabel3.setBounds(10, 295, 300, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjOutputDirLabel3;
}
/**
 * Return the Button2 property value.
 * @return java.awt.Button
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Button getPresets() {
    if (ivjPresets == null) {
        try {
            ivjPresets = new java.awt.Button();
            ivjPresets.setName("Presets");
            ivjPresets.setBounds(465, 273, 56, 23);
            ivjPresets.setLabel("Presets");
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjPresets;
}
/*
 * Return the DriverLabel62 property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getPresetsLabel() {
    if (ivjPresetsLabel == null) {
        try {
            ivjPresetsLabel = new java.awt.Label();
            ivjPresetsLabel.setName("PresetsLabel");
            ivjPresetsLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjPresetsLabel.setText("Presets :");
            ivjPresetsLabel.setBounds(460, 123, 120, 20);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjPresetsLabel;
}
/*
 * Return the DriverLabel62 property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getArchiveLabel() {
    if (ivjArchiveLabel == null) {
        try {
            ivjArchiveLabel = new java.awt.Label();
            ivjArchiveLabel.setName("ArchiveLabel");
            ivjArchiveLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjArchiveLabel.setText("Search in archives :");
            ivjArchiveLabel.setBounds(460, 248, 120, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjArchiveLabel;
}
/*
 * Return the DriverLabel62 property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getSortLabel() {
    if (ivjSortLabel == null) {
        try {
            ivjSortLabel = new java.awt.Label();
            ivjSortLabel.setName("SortLabel");
            ivjSortLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjSortLabel.setText("Sort in order :");
            ivjSortLabel.setBounds(460, 35, 120, 20);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjSortLabel;
}


/** Define the current OS
    * and return command to get info about system
    *
    * Return the String[].
    *
    */
//    public static String[] getPropertyOS() {
public static String getPropertyOS() {
    /*
            String osName = System.getProperty("os.name");
            String[] cmd = new String[3];

            if (osName.equals("Windows NT")) {
                cmd[0] = "cmd.exe";
                cmd[1] = "/C";
            } else
                if (osName.equals("Windows 95")) {
                    cmd[0] = "command.com";
                    cmd[1] = "/C";
                } else
                    if (osName.equals("Windows 98")) {
                        cmd[0] = "command.com";
                        cmd[1] = "/C";
                    } else
                        if (osName.equals("Windows 2000")) {
                            cmd[0] = "cmd.exe";
                            cmd[1] = "/C";
                        }

            return cmd;
    */
    String s = System.getProperty("os.name");
    String s1 = null;
    if (s.equals("Windows NT"))
        s1 = "cmd.exe /C set";
    else
        if (s.equals("Windows 95"))
            s1 = "command.com /C set";
        else
            if (s.equals("Windows 98"))
                s1 = "command.com /C set";
            else
                if (s.equals("Windows 2000"))
                    s1 = "cmd.exe /C set";
                else
                    if (s.equals("Linux")) {
                        s1 = "env";
                        linux = true;
                    }
    return s1;

}
/**
 * Return the Button1 property value.
 * @return java.awt.Button
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Button getStart() {
    if (ivjStart == null) {
        try {
            ivjStart = new java.awt.Button();
            ivjStart.setName("start");
            ivjStart.setBounds(200, 335, 56, 23);
            ivjStart.setLabel("Start");
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjStart;
}
/**
* Return the Checkbox1 property value.
* @return java.awt.Checkbox
*/
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Checkbox getVerbose() {
    if (ivjVerbose == null) {
        try {
            ivjVerbose = new java.awt.Checkbox();
            ivjVerbose.setName("Verbose");
            ivjVerbose.setBounds(417, 300, 20, 23);
            ivjVerbose.setLabel("");
            ivjVerbose.setState(verbose);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjVerbose;
}
/*
 * Return the DriverLabel62 property value.
 * @return java.awt.Label
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private java.awt.Label getVerboseLabel() {
    if (ivjVerboseLabel == null) {
        try {
            ivjVerboseLabel = new java.awt.Label();
            ivjVerboseLabel.setName("VerboseLabel");
            ivjVerboseLabel.setFont(new java.awt.Font("SansSerif", 0, 12));
            ivjVerboseLabel.setText("Show progress :");
            ivjVerboseLabel.setBounds(300, 300, 100, 23);
            // user code begin {1}
            // user code end
        } catch (java.lang.Throwable ivjExc) {
            // user code begin {2}
            // user code end
            handleException(ivjExc);
        }
    }
    return ivjVerboseLabel;
}
/**
     * Called whenever the part throws an exception.
     * @param exception java.lang.Throwable
     */
private void handleException(java.lang.Throwable exception) {

    /* Uncomment the following lines to print uncaught exceptions to stdout */
    // System.out.println("--------- UNCAUGHT EXCEPTION ---------");
    // exception.printStackTrace(System.out);
}
/**
 * Initializes connections
 * @exception java.lang.Exception The exception description.
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private void initConnections() throws java.lang.Exception {
    // user code begin {1}
    // user code end
    getStart().addActionListener(ivjEventHandler);
    getExit().addActionListener(ivjEventHandler);
    getPresets().addActionListener(ivjEventHandler);
    getCheckboxJDK().addItemListener(ivjItemListenerHandler);
    getCheckboxTomcat().addItemListener(ivjItemListenerHandler);
    getCheckboxWebsphere().addItemListener(ivjItemListenerHandler);
    getCheckboxAnt().addItemListener(ivjItemListenerHandler);
}
/**
 * Initialize the class.
 */
/* WARNING: THIS METHOD WILL BE REGENERATED. */
private void initialize() {
    try {
        // user code begin {1}
        ivjMain = getMain();
        ivjExceptDirs.setText(HeliconSystemAnalyzer.exceptDirs);
//        ivjExceptFiles.setText(HeliconSystemAnalyzer.exceptFiles);
        if (!linux) {
            //HeliconSystemAnalyzer.directories = "c:\\; d:\\; e:\\; f:\\";
            HeliconSystemAnalyzer.directories = "c:\\";
        } else {
            HeliconSystemAnalyzer.directories = "/";
        }
        ivjDirectories.setText(HeliconSystemAnalyzer.directories);
  //      ivjOnlyExts.setText(HeliconSystemAnalyzer.onlyExts);
        ivjOnlyNames.setText(HeliconSystemAnalyzer.onlyNames);
//        ivjExceptExts.setText(HeliconSystemAnalyzer.exceptExts);
        //ivjOutputDir.setText(HeliconSystemAnalyzer.outputDir);

        // current path
        java.io.File canonPathRoot = new java.io.File(rootDir);
        String canonPath = canonPathRoot.getCanonicalPath();
        if (!linux) {
            ivjOutputDir.setText(canonPath + "\\" + dateRootDir);
        } else {
            ivjOutputDir.setText(canonPath + "/" + dateRootDir);
        }
        sourcePath = canonPath;

        ivjMain.setVisible(true);
        ivjCreateZip.setState(createZip);
        // user code end
        initConnections();
    } catch (java.lang.Throwable ivjExc) {
        handleException(ivjExc);
    }
}
/**
 * Starts the application, parses the parameters and doing appropriate things.
 * @param argv an array of command-line arguments
 */
public static void main(java.lang.String[] argv) {

    if (argv.length == 0) {
        HeliconSystemAnalyzer db2t = new HeliconSystemAnalyzer();
    } else {
        for (int i = 0; i < argv.length; i++) {
            String arg = argv[i];
            interactive = true;
            if (arg.equals("-d") || arg.equals("--directories")) {
                HeliconSystemAnalyzer.directories = getArg(argv, ++i);
            } else
                if (arg.equals("-oe") || arg.equals("--onlyExts")) {
                    HeliconSystemAnalyzer.onlyExts = getArg(argv, ++i);
                } else
                    if (arg.equals("-on") || arg.equals("--onlyNames")) {
                        HeliconSystemAnalyzer.onlyNames = getArg(argv, ++i);
                    } else
                        if (arg.equals("-ed") || arg.equals("--exceptDirs")) {
                            HeliconSystemAnalyzer.exceptDirs = getArg(argv, ++i);
                        } else
                            if (arg.equals("-ef") || arg.equals("--exceptFiles")) {
                                HeliconSystemAnalyzer.exceptFiles = getArg(argv, ++i);
                            } else
                                if (arg.equals("-ee") || arg.equals("--exceptExts")) {
                                    HeliconSystemAnalyzer.exceptExts = getArg(argv, ++i);
                                } else
                                    if (arg.equals("-od") || arg.equals("--outputDir")) {
                                        HeliconSystemAnalyzer.outputDir = getArg(argv, ++i);
                                    } else
                                        if (arg.equalsIgnoreCase("-cz") || arg.equals("--createZip")) {
                                            createZip = true;
                                        } else
                                            if (arg.equalsIgnoreCase("-sp") || arg.equals("--showProgress")) {
                                                verbose = true;
                                            } else
                                                if (arg.equals("-h") || arg.equals("--help")) {
                                                    usage();
                                                    exit();
                                                }

        } //end for
        if (HeliconSystemAnalyzer.directories == null) {
            usage();
            exit();
        }
        if (interactive) {
            HeliconSystemAnalyzer db2t = new HeliconSystemAnalyzer(interactive);
        }

    }

}
/**
 * Return the BufferedReader.
 * @return java.util.BufferedReader
 */

public static BufferedReader OutStream(InputStream is, String type) {

    PrintWriter pw = null;

    InputStreamReader isr = new InputStreamReader(is);
    br = new BufferedReader(isr);

    return br;
}
public static void runIndex(String indexPath) {

    /*
                String osName = System.getProperty("os.name" );
                String cmd = null;

                if( osName.equals( "Windows NT" ) )
                {
                    cmd = "cmd.exe /C set" ;
    //                cmd[1] = "/C" ;
                }
                else if( osName.equals( "Windows 95" ) )
                {
    				cmd = "command.com /C set" ;
    //                cmd[1] = "/C" ;
                }
                else if( osName.equals( "Windows 98" ) )
                {
                    cmd = "command.com /C set" ;
    //                cmd[1] = "/C" ;
                }

                else if( osName.equals( "Windows 2000" ) )
                {
    //                cmd = "cmd.exe /C start \"C:\\test\\index.html\"" ;
                    cmd = "cmd.exe /C start \""+indexPath+"\\index.html\"" ;

    //                cmd[1] = "/C" ;
                }
    			else if( osName.equals( "Linux" ) )
                {
                    cmd = "env" ;
    //                cmd[1] = "" ;
                    linux = true;
                }
    */

    try {
        Runtime rt = Runtime.getRuntime();

        if (!linux) {
            Process proc = rt.exec("explorer.exe " + indexPath + "\\index.html");
        } else {
            System.out.println(
                "!!!!!!!!!!!!!!!!!  konqueror ="
                    + "/usr/bin/konqueror "
                    + indexPath
                    + java.io.File.separator
                    + "index.html");
            //Process proc = rt.exec("/usr/bin/konqueror " + indexPath + java.io.File.separator+"index.html");
            Process proc =
                rt.exec("netscape " + indexPath + java.io.File.separator + "index.html");
        }

    } catch (Throwable t) {
        t.printStackTrace();
    }
}
/**
 * Execute command to get system info
 *
 */
//    public static void runtime(String[] cmd) {
public static void runtime(String s) {

    try {
        //            Runtime rt = Runtime.getRuntime();

        //            System.out.println("Execing " + cmd[0] + " " + cmd[1]
        //                               + " " + cmd[2]);
        //            Process proc = rt.exec(cmd);

        //            BufferedReader br = OutStream(proc.getInputStream(), "OUTPUT");

        Runtime runtime1 = Runtime.getRuntime();
        Process process = runtime1.exec(s);
        OutStream(process.getInputStream(), "OUTPUT");

    } catch (Throwable t) {
        t.printStackTrace();
    }
}
public void runtimeOtherJava() {
    Object obj = null;
    Object obj1 = null;
    java.util.Properties properties = System.getProperties();
    String s;
    String s1;
    for (Enumeration enumeration = properties.keys();
        enumeration.hasMoreElements();
        tmOutSystem.put(s, s1)) {
        s = (String) enumeration.nextElement();
        s1 = System.getProperty(s);
        if (findPath) {
            findInputDir(s1);
        }
    }

}
/**
 * Sets inputed list of directories and invokes classes to create HTML files and ZIP file
 */

public void setDirectories() {

    String[] cmd = new String[3];
    String curdir = null;
    alDirList = new java.util.ArrayList();

    StringTokenizer token = null;

    if (directories != null) {

        token = new StringTokenizer(directories, delimiter);

        while (token.hasMoreTokens()) {

            String dir = token.nextToken().trim();

            java.io.File curr_dir = new java.io.File(dir);
            String s[] = curr_dir.list();

            if (s == null) {

                System.out.println("Folder:" + dir + " does not exist.");
                continue;

            } //end if

            //if (dir.endsWith("\\") && dir.length() != 3) {
            if (dir.endsWith(java.io.File.separator) && dir.length() != 3) {
                dir = dir.substring(0, dir.length() - 1);
            }
            // list of all inputed directories
            alDirList.add(dir);

        }
    }

    int t = alDirList.size();

    if (alDirList.size() == 0) {

        System.out.println("No folder with entered name is found!");
        System.exit(0);

    }

    DirInfo ds = new DirInfo(contentsJar, contentsZip);

    ds.sbody = ds.HTMLProducerSystem(ds.sbody, alRuntimeSystem);

    System.out.println("Please wait.....process is running... ");

    java.util.ArrayList alhtOut = new java.util.ArrayList();
    java.util.ArrayList altmOutSystem = new java.util.ArrayList();
    //
    for (int b = 0; b < alDirList.size(); b++) {
        int t2 = alDirList.size();
        ds.currCount = 0;
        try {
            ds.ht = new java.util.TreeMap();
            this.currDir = (String) alDirList.get(b);

            ds.getDir((String) alDirList.get(b));
        } catch (Exception e) {
        }

        // creating list of directories and files for output
        ds.FillingBody(br, exceptDirs, exceptFiles, exceptExts, onlyExts, onlyNames);

        // some folder with files after shifting
        this.htOut = ds.htOut;

        this.tmListsJar = ds.tmListsJar;

        java.util.ArrayList alFilesTime = new java.util.ArrayList();

        //new treeMap without exmpty directories
        java.util.TreeMap htOutWithoutEmpty = new java.util.TreeMap();

        java.util.TreeMap htTIME = new java.util.TreeMap();

        String key = null;
        boolean exceptDir = false;
        java.util.Iterator iter = null;

        iter = this.htOut.keySet().iterator();

        htTIME = this.htOut;

        // throw lists of directories
        for (int i = 0; iter.hasNext(); i++) {

            exceptDir = false;
            key = (String) iter.next();
            alFilesTime = (java.util.ArrayList) this.htOut.get(key);

            //alFilesTime = (java.util.ArrayList) iter.next();
            if (alFilesTime.isEmpty()) {
                exceptDir = true;
            }

            // add to new lists of directories

            if (!exceptDir)
                htOutWithoutEmpty.put(key, alFilesTime);

        }

        // redefinition htOut without empty direcotries
        this.htOut = htOutWithoutEmpty;

        this.tmOutSystem = ds.tmSystemOut;
        // add other system environment
        runtimeOtherJava();

        //all directories with their files after shifting
        alhtOut.add(this.htOut);

        altmOutSystem.add(this.tmOutSystem);

        ds.htOut = new java.util.TreeMap();
    }

    this.containsContentsJar = ds.contRepeatedContentJar;

    this.containsFiles = ds.contRepFiles;
    this.alFilesAll = ds.containsObjectFilesAll;
    this.alContentsAllJar = ds.alListAllContentJar;
    this.htContentsAllJar = ds.htListAllContentJar;

    this.alListAllJars = ds.alListAllJars;

    createTMRepeatedContentsJar();

    // throw all directories after sifting
    for (int b = 0; b < alhtOut.size(); b++) {

        String time = (String) alDirList.get(b);

        java.util.ArrayList alTime2 = new java.util.ArrayList();
        alTime2 = alDirList;

        this.currDir = (String) alDirList.get(b);
        // all files in some folder after sifting
        this.htOut = (java.util.TreeMap) alhtOut.get(b);
        this.tmOutSystem = (java.util.TreeMap) altmOutSystem.get(b);

        generateOther(this.htOut, this.currDir);
    }

    java.util.ArrayList timeFiles = this.containsFiles;
    java.util.ArrayList timeAL = this.alFilesAll;

    createTMFilesDir();
    //java.util.TreeMap timehtContentsJar = htContentsJar ;

    generate();

    //generate images
    generateImages();

    if (createZip) {
        java.util.ArrayList alDirZipList = new java.util.ArrayList();

        alDirZipList.add("images");
        alDirZipList.add("variables");
        alDirZipList.add("AllFiles");
        alDirZipList.add("AllJars");
        alDirZipList.add("dirsForFile");
        alDirZipList.add("jarsForContent");
        alDirZipList.add("allobjects.html");
        alDirZipList.add("index.html");
        alDirZipList.add("main.html");
        alDirZipList.add("right.html");
        alDirZipList.add("stylesheet.css");

        DirCycle dirCycle = new DirCycle(outputDir, verbose, dateRootDir);

        int time = alDirList.size();

        try {
            for (int b = 0; b < alDirList.size(); b++) {
                if (!linux) {

                    dirCycle.getDir(
                        rootDir
                            + (String) alDirList.get(b).toString().substring(0, 1)
                            + java.io.File.separator
                            + (String) alDirList.get(b).toString().substring(
                                3,
                                alDirList.get(b).toString().length()));
                } else {
                    dirCycle.getDir(rootDir + alDirList.get(b).toString());
                }
            }

            for (int i = 0; i < alDirZipList.size(); i++) {
                dirCycle.getDir(rootDir + (String) alDirZipList.get(i));
            }

            dirCycle.finallyMethod();
        } catch (Exception e) {
        }

    } // end if

    try {

//        java.io.File canonPathRoot = new java.io.File(rootDir);
//        String canonPath = canonPathRoot.getCanonicalPath();
        String canonPath = fullPath();
        System.out.println();
        System.out.println("index.html is located in " + canonPath);
        runIndex(canonPath);

    } catch (java.lang.Exception e) {
        System.err.println("An error occured");
        e.printStackTrace();
    } //end catch

    System.exit(1);

    //	return listDirectories;
}
private String fullPath(){
        String canonPath = null;
        try{
          java.io.File canonPathRoot = new java.io.File(rootDir);
          canonPath = canonPathRoot.getCanonicalPath();
        } catch (java.lang.Exception e) {
          System.err.println("An error occured in fullPath method");
          e.printStackTrace();
    } //end catch
        return canonPath ;
}
public void setHelp() {

    if (this.getCheckboxTomcat().getState()) {

        if (!flagTomcat)
            setTextFieldHelp("Tomcat", true);
        flagTomcat = true;
    } else {
        if (flagTomcat)
            setTextFieldHelp("Tomcat", false);
        flagTomcat = false;
    }

    if (this.getCheckboxJDK().getState()) {
        if (!flagJDK)
            setTextFieldHelp("JDK", true);
        flagJDK = true;
    } else {
        if (flagJDK)
            setTextFieldHelp("JDK", false);
        flagJDK = false;
    }

    if (this.getCheckboxWebsphere().getState()) {
        if (!flagWebsphere)
            setTextFieldHelp("Websphere", true);
        flagWebsphere = true;
    } else {
        if (flagWebsphere)
            setTextFieldHelp("Websphere", false);
        flagWebsphere = false;
    }
    if (this.getCheckboxAnt().getState()) {
        if (!flagAnt)
            setTextFieldHelp("Ant", true);
        flagAnt = true;
    } else {
        if (flagAnt)
            setTextFieldHelp("Ant", false);
        flagAnt = false;
    }

}
public void setTextFieldHelp(String type, boolean state) {

    java.util.ArrayList alCurrent = new java.util.ArrayList();
    java.util.ArrayList alCurrentExts = new java.util.ArrayList();

    alCurrent = (java.util.ArrayList) tmHelp.get(type);

    if (state) {
        for (int b = 0; b < alCurrent.size(); b++) {

            int involveTrue =
                ivjOnlyNames.getText().indexOf((String) alCurrent.get(b) + ";");
            if (involveTrue == 0) {
                String ok = null;
            } else {
                involveTrue =
                    ivjOnlyNames.getText().indexOf(";" + (String) alCurrent.get(b) + ";");
            }

            if (involveTrue == -1) {
                ivjOnlyNames.setText(ivjOnlyNames.getText() + alCurrent.get(b) + ";");
            } // end if
            if (currentLineMust == null) {
                currentLineMust = alCurrent.get(b) + ";";
            } else {
                currentLineMust = currentLineMust + alCurrent.get(b) + ";";
            }

        } // end for
    } // end if
    else {
        for (int b = 0; b < alCurrent.size(); b++) {

            ///////
            int one = 0;
            int involveTrueOutMust =
                currentLineMust.indexOf((String) alCurrent.get(b) + ";");
            if (involveTrueOutMust == 0) {
                one = 0;
            } else {
                involveTrueOutMust =
                    currentLineMust.indexOf(";" + (String) alCurrent.get(b) + ";");
                one = 1;
            }

            StringBuffer currentStringMust = new StringBuffer(currentLineMust);

            String strInCurr = (String) alCurrent.get(b);
            int lengthStringInCurr = strInCurr.length();

            if (involveTrueOutMust != -1) {
                currentStringMust.replace(
                    involveTrueOutMust + one,
                    involveTrueOutMust + one + lengthStringInCurr + 1,
                    "");
            } //end if

            currentLineMust = currentStringMust.toString();

            //////////////
            int mustIn = currentLineMust.indexOf((String) alCurrent.get(b) + ";");

            if (mustIn == 0) {
                String ok = null;
            } else {
                mustIn = currentLineMust.indexOf(";" + (String) alCurrent.get(b) + ";");
            }

            if (mustIn == -1) {

                int involveTrueOut =
                    ivjOnlyNames.getText().indexOf((String) alCurrent.get(b) + ";");
                if (involveTrueOut == 0) {
                    String ok = null;
                    one = 0;
                } else {
                    involveTrueOut =
                        ivjOnlyNames.getText().indexOf(";" + (String) alCurrent.get(b) + ";");
                    one = 1;
                }

                if (involveTrueOut != -1) {

                    StringBuffer currentStringSB = new StringBuffer(ivjOnlyNames.getText());
                    String strIn = (String) alCurrent.get(b);
                    int lengthStringIn = strIn.length();
                    currentStringSB.replace(
                        involveTrueOut + one,
                        involveTrueOut + one + lengthStringIn + 1,
                        "");
                    ivjOnlyNames.setText(currentStringSB.toString());
                    ///

                } // end if
            } //end if

        } // end for

    } //end else
/*
    alCurrent = (java.util.ArrayList) tmHelpExts.get(type);

    if (state) {
        for (int b = 0; b < alCurrent.size(); b++) {

            int involveTrue = ivjOnlyExts.getText().indexOf((String) alCurrent.get(b));
            if (involveTrue == -1) {
                ivjOnlyExts.setText(ivjOnlyExts.getText() + alCurrent.get(b) + ";");
            } // end if
            if (currentLineMustExts == null) {
                currentLineMustExts = alCurrent.get(b) + ";";
            } else {
                currentLineMustExts = currentLineMustExts + alCurrent.get(b) + ";";
            }

        } // end for
    } // end if
    else {
        for (int b = 0; b < alCurrent.size(); b++) {

            ///////
            int involveTrueOutMustExts =
                currentLineMustExts.indexOf((String) alCurrent.get(b));

            StringBuffer currentStringMustExts = new StringBuffer(currentLineMustExts);

            String strInCurrExts = (String) alCurrent.get(b);
            int lengthStringInCurrExts = strInCurrExts.length();

            if (involveTrueOutMustExts != -1) {
                currentStringMustExts.replace(
                    involveTrueOutMustExts,
                    involveTrueOutMustExts + lengthStringInCurrExts + 1,
                    "");
            } //end if

            currentLineMustExts = currentStringMustExts.toString();

            //////////////

            int mustIn = currentLineMustExts.indexOf((String) alCurrent.get(b));
            if (mustIn == -1) {

                int involveTrueOut = ivjOnlyExts.getText().indexOf((String) alCurrent.get(b));
                if (involveTrueOut != -1) {

                    StringBuffer currentStringSB = new StringBuffer(ivjOnlyExts.getText());
                    String strIn = (String) alCurrent.get(b);
                    int lengthStringIn = strIn.length();
                    currentStringSB.replace(
                        involveTrueOut,
                        involveTrueOut + lengthStringIn + 1,
                        "");
                    ivjOnlyExts.setText(currentStringSB.toString());
                    ///

                } // end if
            } //end if

        } // end for

    } //end else
*/
}
/**
 * Handles the START button pressing
 */
public void startbutton_ActionPerformed(
    java.awt.event.ActionEvent actionEvent) {

    HeliconSystemAnalyzer.exceptDirs = ivjExceptDirs.getText();
//   HeliconSystemAnalyzer.exceptFiles = ivjExceptFiles.getText();
    HeliconSystemAnalyzer.directories = ivjDirectories.getText();
//    HeliconSystemAnalyzer.onlyExts = ivjOnlyExts.getText();
//    HeliconSystemAnalyzer.onlyNames = ivjOnlyNames.getText();
//    HeliconSystemAnalyzer.exceptExts = ivjExceptExts.getText();
    HeliconSystemAnalyzer.outputDir = ivjOutputDir.getText();

    ivjMain.setVisible(false);
    ivjMain = null;

    if ((HeliconSystemAnalyzer.directories == null)
        || (HeliconSystemAnalyzer.directories.equals(""))
        || (HeliconSystemAnalyzer.directories.equals(" "))) {
        System.out.println("You have not specified any folder");
        System.exit(0);
    }
    createZip = ivjCreateZip.getState();
    verbose = ivjVerbose.getState();

    contentsJar = ivjCheckboxJAR.getState();
    contentsZip = ivjCheckboxZIP.getState();

    sortOrder = ivjCheckboxGroupSort.getSelectedCheckbox().getLabel();
    if ("Name".equals(sortOrder)){
      sortNumber = 1;
    }else if("Date".equals(sortOrder)){
      sortNumber = 2;
    }else if("Size".equals(sortOrder)){
      sortNumber = 3;
    }
    setDirectories();

    return;
}
/**
 * Prints usage information to the standard output
 */
static void usage() {
    System.out.println(
        "Usage: java helicon.HeliconSystemAnalyzer [-options] -directories <directories> -exceptDirs <exceptDirs>  ");
    System.out.println();
    System.out.println("where options include");
    System.out.println(
        "-d or --directories <directories> names of directories (default JDK)");
    System.out.println(
        "-of or --onlyNames <onlyFiles> names of directories and files ");

    System.out.println(
        "-ed or --exceptDirs <exceptDirs> names of excepted directories ");
    System.out.println(
        "-od or --outputDir <folder> names of output folder (default: current folder)");
    System.out.println();
    System.out.println("-cz or --createZip switches createZip mode on");
    System.out.println("-sp or --showProgress output information into console");
    System.out.println();
    System.out.println("-h or --help prints usage message and exist");
    System.out.println(" The names should be semicolon-separated");
    System.out.println();
    System.out.println(
        " i.e.  HeliconSystemAnalyzer.bat -d \"c:\\test;c:\\testDir2\" -ed \"lib;bin\"  -of \"helicon.jar; helicon.txt\" -od c:\\outputDir -sp -cz ");
    System.out.println();
    System.out.println(
        " i.e.  HeliconSystemAnalyzer.bat -d c:\\test -ed \"lib;bin\" -of c:\\outputDir -cz ");
}

public void generateImages(){

    byte[] byteArray, byteArrayContents;

try{
   String canonPath = fullPath();
   new java.io.File(canonPath + java.io.File.separator + "images").mkdirs();

//  char c = 0xffff; // max char hex value
//  byte b = 0x7f; // max byte hex value
//  short s = 0x7fff; // max short hex value
//    byteArray = new byte[150];
//38 D2 8A 78 12 01 00 3B
//    for(int i = 0; i < 150; i++){
//      byte B = (byte)i;
//      byteArray[i] = B;
//      }
//   byte b = 0x47;
//   byte b2 = 0xB3 - 256;
//    byte[] byteArr = {0x47, b2, b};
//    byte[] byteArr = { 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x0E, 0x00, 0x0E, 0x00, 0xB3, 0x00, 0x00, 0x00, 0x00, 0x00};
/*
   byte[] byteArr = { 0x47, 0x49, 0x46, 0x38, 0x39, 0x61, 0x0E, 0x00, 0x0E, 0x00, 0xB3, 0x00, 0x00, 0x00, 0x00, 0x00,+
 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0xFF, 0x90, 0x90, 0xFF, 0xA6, 0xCA, 0xF0, 0x00, 0xAC, 0xF0, 0xFF,+
 0xFB, 0xF0, 0xC5, 0xC5, 0xC5, 0xFF, 0xFF, 0xFF, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,+
 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x21, 0xF9, 0x04,+
 0x01, 0x00, 0x00, 0x08, 0x00, 0x2C, 0x00, 0x00, 0x00, 0x00, 0x0E, 0x00, 0x0E, 0x00, 0x00, 0x04,+
 0x43, 0xB0, 0xC8, 0x49, 0xA5, 0x18, 0xC5, 0x68, 0x2D, 0xB7, 0xB9, 0x19, 0x21, 0x1A, 0x13, 0xA1,+
 0x81, 0xDE, 0x96, 0x9D, 0x98, 0x41, 0x1C, 0xC7, 0x20, 0x90, 0x87, 0x21, 0xB7, 0xA2, 0x3C, 0x17,+
 0x84, 0xDE, 0xDA, 0x82, 0xA0, 0x50, 0xD8, 0xD1, 0x0D, 0x85, 0x98, 0x90, 0x71, 0x38, 0x20, 0xAD,+
 0x80, 0x3B, 0x4F, 0xE7, 0x15, 0xDB, 0xD5, 0x6A, 0xD3, 0x91, 0x89, 0xE7, 0x72, 0xA6, 0x38, 0xD2,+
 0x8A, 0x78, 0x12, 0x01, 0x00, 0x3B  };
*/

    java.io.BufferedReader fReader, fReaderContents;
    ClassLoader clLoader = getClassLoader();

//getAppletContext().showDocument(new java.net.URL(sb.toString()), "_new");

    java.net.URL fURL = clLoader.getResource("images/goto.gif");
System.out.println("3");
//
   new java.io.File(canonPath + java.io.File.separator + "images2").mkdirs();


    //String listLoacation = "/resources/my.properties";
    String listLoacation = "/images/goto.gif";
    String listLoacationContents = "/images/contents.gif";
    InputStream is, isContents;
    is = getClass().getResourceAsStream(listLoacation);
    if (is == null) throw new Exception("resource "+listLoacation+" was not found");
    fReader = new java.io.BufferedReader(new java.io.InputStreamReader( is) );

////
    isContents = getClass().getResourceAsStream(listLoacationContents);
    if (isContents == null) throw new Exception("resource "+listLoacationContents+" was not found");
    fReaderContents = new java.io.BufferedReader(new java.io.InputStreamReader( isContents) );


//      java.net.URLConnection urlCon = fURL.openConnection();
//      fReader = new java.io.BufferedReader(new java.io.InputStreamReader( fURL.openStream()) );

//      java.net.URL fURLContents = clLoader.getResource("images/contents.gif");
//      fReaderContents = new java.io.BufferedReader(new java.io.InputStreamReader( fURLContents.openStream()) );


    //   String canonPath = fullPath();
    String s, s2 = new String();

    while((s = fReader.readLine())!= null){
      s2 += s;
      }

    byteArray = s2.getBytes();
    fReader.close();

    String sContents, s2Contents = new String();

    while((sContents = fReaderContents.readLine())!= null){
      s2Contents += sContents;
      }
    byteArrayContents = s2Contents.getBytes();
    fReaderContents.close();

 DataOutputStream out2 =
        new DataOutputStream(
          new BufferedOutputStream(
            new FileOutputStream(canonPath + java.io.File.separator + "images\\goto.gif")));
//      out2.writeDouble(3.14159);
//      out2.writeChars("That was pi\n");
//      out2.writeBytes("GIF89a");
//      out2.writeByte(0x47);
//      out2.writeByte("#47");
        out2.write(byteArray);
        out2.flush();
        out2.close();


//
 DataOutputStream out2Contents =
        new DataOutputStream(
          new BufferedOutputStream(
            new FileOutputStream(canonPath + java.io.File.separator + "images\\contents.gif")));
        out2Contents.write(byteArrayContents);
        out2Contents.flush();
        out2Contents.close();

    } catch(EOFException e) {
      System.err.println("Error in EOFException");
    } catch(java.io.FileNotFoundException e) {
      System.err.println("Error in FileNotFoundException");
    } catch(java.io.IOException e) {
      System.err.println("Error in IOException");
    } catch(java.lang.Exception ex){
      System.err.println("Error in generateImages method");
      System.out.println("Can't load property list: "+ex.getMessage());
    }

}
static private java.util.ArrayList resortData(java.util.ArrayList al, int sortNumber){
                // sort comparator
                java.util.Comparator cmp;
                cmp = new DataComparator(sortNumber);
                java.util.Collections.sort(al, cmp);
                return al;
}
/**
 * Returns the SystemClassLoader
 *
 * @return java.lang.ClassLoader
 */
private static java.lang.ClassLoader getClassLoader() {

    java.lang.ClassLoader loader = ClassLoader.getSystemClassLoader();

    return loader;
}

}